@@ -12,16 +12,15 @@
 #
 
 """Base API Library"""
-
 from keystoneauth1 import exceptions as ks_exceptions
 from keystoneauth1 import session as ks_session
 from osc_lib import exceptions
-import simplejson as json
+import requests
 
 from openstackclient.i18n import _
 
 
-class KeystoneSession(object):
+class KeystoneSession:
     """Wrapper for the Keystone Session
 
     Restore some requests.session.Session compatibility;
@@ -40,7 +39,7 @@ class KeystoneSession(object):
             requests on this API.
         """
 
-        super(KeystoneSession, self).__init__()
+        super().__init__()
 
         # a requests.Session-style interface
         self.session = session
@@ -95,7 +94,7 @@ class BaseAPI(KeystoneSession):
             requests on this API.
         """
 
-        super(BaseAPI, self).__init__(session=session, endpoint=endpoint)
+        super().__init__(session=session, endpoint=endpoint)
 
         self.service_type = service_type
 
@@ -118,7 +117,7 @@ class BaseAPI(KeystoneSession):
         # Should this move into _requests()?
         try:
             return ret.json()
-        except json.JSONDecodeError:
+        except requests.JSONDecodeError:
             return ret
 
     def delete(self, url, session=None, **params):
@@ -169,7 +168,7 @@ class BaseAPI(KeystoneSession):
             )
         try:
             return ret.json()
-        except json.JSONDecodeError:
+        except requests.JSONDecodeError:
             return ret
 
     # Layered actions built on top of the basic action methods do not
@@ -303,7 +302,7 @@ class BaseAPI(KeystoneSession):
         """
 
         try:
-            ret = self._request('GET', "/%s/%s" % (path, value)).json()
+            ret = self._request('GET', f"/{path}/{value}").json()
         except ks_exceptions.NotFound:
             kwargs = {attr: value}
             try:
