@@ -20,7 +20,6 @@ import logging
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
-import six
 
 from openstackclient.i18n import _
 from openstackclient.identity import common
@@ -33,7 +32,7 @@ class CreateCredential(command.ShowOne):
     _description = _("Create new credential")
 
     def get_parser(self, prog_name):
-        parser = super(CreateCredential, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'user',
             metavar='<user>',
@@ -43,8 +42,7 @@ class CreateCredential(command.ShowOne):
             '--type',
             default="cert",
             metavar='<type>',
-            choices=['ec2', 'cert'],
-            help=_('New credential type: cert, ec2'),
+            help=_('New credential type: cert, ec2, totp and so on'),
         )
         parser.add_argument(
             'data',
@@ -54,35 +52,40 @@ class CreateCredential(command.ShowOne):
         parser.add_argument(
             '--project',
             metavar='<project>',
-            help=_('Project which limits the scope of '
-                   'the credential (name or ID)'),
+            help=_(
+                'Project which limits the scope of '
+                'the credential (name or ID)'
+            ),
         )
         return parser
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
-        user_id = utils.find_resource(identity_client.users,
-                                      parsed_args.user).id
+        user_id = utils.find_resource(
+            identity_client.users, parsed_args.user
+        ).id
         if parsed_args.project:
-            project = utils.find_resource(identity_client.projects,
-                                          parsed_args.project).id
+            project = utils.find_resource(
+                identity_client.projects, parsed_args.project
+            ).id
         else:
             project = None
         credential = identity_client.credentials.create(
             user=user_id,
             type=parsed_args.type,
             blob=parsed_args.data,
-            project=project)
+            project=project,
+        )
 
         credential._info.pop('links')
-        return zip(*sorted(six.iteritems(credential._info)))
+        return zip(*sorted(credential._info.items()))
 
 
 class DeleteCredential(command.Command):
     _description = _("Delete credential(s)")
 
     def get_parser(self, prog_name):
-        parser = super(DeleteCredential, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'credential',
             metavar='<credential-id>',
@@ -99,14 +102,19 @@ class DeleteCredential(command.Command):
                 identity_client.credentials.delete(i)
             except Exception as e:
                 result += 1
-                LOG.error(_("Failed to delete credentials with "
-                          "ID '%(credential)s': %(e)s"),
-                          {'credential': i, 'e': e})
+                LOG.error(
+                    _(
+                        "Failed to delete credentials with "
+                        "ID '%(credential)s': %(e)s"
+                    ),
+                    {'credential': i, 'e': e},
+                )
 
         if result > 0:
             total = len(parsed_args.credential)
-            msg = (_("%(result)s of %(total)s credential failed "
-                   "to delete.") % {'result': result, 'total': total})
+            msg = _(
+                "%(result)s of %(total)s credential failed " "to delete."
+            ) % {'result': result, 'total': total}
             raise exceptions.CommandError(msg)
 
 
@@ -114,7 +122,7 @@ class ListCredential(command.Lister):
     _description = _("List credentials")
 
     def get_parser(self, prog_name):
-        parser = super(ListCredential, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             '--user',
             metavar='<user>',
@@ -124,8 +132,7 @@ class ListCredential(command.Lister):
         parser.add_argument(
             '--type',
             metavar='<type>',
-            choices=['ec2', 'cert'],
-            help=_('Filter credentials by type: cert, ec2'),
+            help=_('Filter credentials by type: cert, ec2, totp and so on'),
         )
         return parser
 
@@ -147,18 +154,24 @@ class ListCredential(command.Lister):
         columns = ('ID', 'Type', 'User ID', 'Blob', 'Project ID')
         column_headers = ('ID', 'Type', 'User ID', 'Data', 'Project ID')
         data = self.app.client_manager.identity.credentials.list(**kwargs)
-        return (column_headers,
-                (utils.get_item_properties(
-                    s, columns,
+        return (
+            column_headers,
+            (
+                utils.get_item_properties(
+                    s,
+                    columns,
                     formatters={},
-                ) for s in data))
+                )
+                for s in data
+            ),
+        )
 
 
 class SetCredential(command.Command):
     _description = _("Set credential properties")
 
     def get_parser(self, prog_name):
-        parser = super(SetCredential, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'credential',
             metavar='<credential-id>',
@@ -173,9 +186,8 @@ class SetCredential(command.Command):
         parser.add_argument(
             '--type',
             metavar='<type>',
-            choices=['ec2', 'cert'],
             required=True,
-            help=_('New credential type: cert, ec2'),
+            help=_('New credential type: cert, ec2, totp and so on'),
         )
         parser.add_argument(
             '--data',
@@ -186,35 +198,41 @@ class SetCredential(command.Command):
         parser.add_argument(
             '--project',
             metavar='<project>',
-            help=_('Project which limits the scope of '
-                   'the credential (name or ID)'),
+            help=_(
+                'Project which limits the scope of '
+                'the credential (name or ID)'
+            ),
         )
         return parser
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
 
-        user_id = utils.find_resource(identity_client.users,
-                                      parsed_args.user).id
+        user_id = utils.find_resource(
+            identity_client.users, parsed_args.user
+        ).id
 
         if parsed_args.project:
-            project = utils.find_resource(identity_client.projects,
-                                          parsed_args.project).id
+            project = utils.find_resource(
+                identity_client.projects, parsed_args.project
+            ).id
         else:
             project = None
 
-        identity_client.credentials.update(parsed_args.credential,
-                                           user=user_id,
-                                           type=parsed_args.type,
-                                           blob=parsed_args.data,
-                                           project=project)
+        identity_client.credentials.update(
+            parsed_args.credential,
+            user=user_id,
+            type=parsed_args.type,
+            blob=parsed_args.data,
+            project=project,
+        )
 
 
 class ShowCredential(command.ShowOne):
     _description = _("Display credential details")
 
     def get_parser(self, prog_name):
-        parser = super(ShowCredential, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'credential',
             metavar='<credential-id>',
@@ -224,8 +242,9 @@ class ShowCredential(command.ShowOne):
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
-        credential = utils.find_resource(identity_client.credentials,
-                                         parsed_args.credential)
+        credential = utils.find_resource(
+            identity_client.credentials, parsed_args.credential
+        )
 
         credential._info.pop('links')
-        return zip(*sorted(six.iteritems(credential._info)))
+        return zip(*sorted(credential._info.items()))
