@@ -18,7 +18,7 @@
 import copy
 import logging
 
-from keystoneauth1 import exceptions as ks_exc
+from openstack import exceptions as sdk_exc
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
@@ -30,6 +30,33 @@ from openstackclient.identity import common
 LOG = logging.getLogger(__name__)
 
 
+def _format_user(user):
+    columns = (
+        'default_project_id',
+        'domain_id',
+        'email',
+        'is_enabled',
+        'id',
+        'name',
+        'description',
+        'password_expires_at',
+    )
+    column_headers = (
+        'default_project_id',
+        'domain_id',
+        'email',
+        'enabled',
+        'id',
+        'name',
+        'description',
+        'password_expires_at',
+    )
+    return (
+        column_headers,
+        utils.get_item_properties(user, columns),
+    )
+
+
 def _get_options_for_user(identity_client, parsed_args):
     options = {}
     if parsed_args.ignore_lockout_failure_attempts:
@@ -53,8 +80,9 @@ def _get_options_for_user(identity_client, parsed_args):
     if parsed_args.disable_multi_factor_auth:
         options['multi_factor_auth_enabled'] = False
     if parsed_args.multi_factor_auth_rule:
-        auth_rules = [rule.split(",") for rule in
-                      parsed_args.multi_factor_auth_rule]
+        auth_rules = [
+            rule.split(",") for rule in parsed_args.multi_factor_auth_rule
+        ]
         if auth_rules:
             options['multi_factor_auth_rules'] = auth_rules
     return options
@@ -66,54 +94,70 @@ def _add_user_options(parser):
     parser.add_argument(
         '--ignore-lockout-failure-attempts',
         action="store_true",
-        help=_('Opt into ignoring the number of times a user has '
-               'authenticated and locking out the user as a result'),
+        help=_(
+            'Opt into ignoring the number of times a user has '
+            'authenticated and locking out the user as a result'
+        ),
     )
     parser.add_argument(
         '--no-ignore-lockout-failure-attempts',
         action="store_true",
-        help=_('Opt out of ignoring the number of times a user has '
-               'authenticated and locking out the user as a result'),
+        help=_(
+            'Opt out of ignoring the number of times a user has '
+            'authenticated and locking out the user as a result'
+        ),
     )
     parser.add_argument(
         '--ignore-password-expiry',
         action="store_true",
-        help=_('Opt into allowing user to continue using passwords that '
-               'may be expired'),
+        help=_(
+            'Opt into allowing user to continue using passwords that '
+            'may be expired'
+        ),
     )
     parser.add_argument(
         '--no-ignore-password-expiry',
         action="store_true",
-        help=_('Opt out of allowing user to continue using passwords '
-               'that may be expired'),
+        help=_(
+            'Opt out of allowing user to continue using passwords '
+            'that may be expired'
+        ),
     )
     parser.add_argument(
         '--ignore-change-password-upon-first-use',
         action="store_true",
-        help=_('Control if a user should be forced to change their password '
-               'immediately after they log into keystone for the first time. '
-               'Opt into ignoring the user to change their password during '
-               'first time login in keystone'),
+        help=_(
+            'Control if a user should be forced to change their password '
+            'immediately after they log into keystone for the first time. '
+            'Opt into ignoring the user to change their password during '
+            'first time login in keystone'
+        ),
     )
     parser.add_argument(
         '--no-ignore-change-password-upon-first-use',
         action="store_true",
-        help=_('Control if a user should be forced to change their password '
-               'immediately after they log into keystone for the first time. '
-               'Opt out of ignoring the user to change their password during '
-               'first time login in keystone'),
+        help=_(
+            'Control if a user should be forced to change their password '
+            'immediately after they log into keystone for the first time. '
+            'Opt out of ignoring the user to change their password during '
+            'first time login in keystone'
+        ),
     )
     parser.add_argument(
         '--enable-lock-password',
         action="store_true",
-        help=_('Disables the ability for a user to change its password '
-               'through self-service APIs'),
+        help=_(
+            'Disables the ability for a user to change its password '
+            'through self-service APIs'
+        ),
     )
     parser.add_argument(
         '--disable-lock-password',
         action="store_true",
-        help=_('Enables the ability for a user to change its password '
-               'through self-service APIs'),
+        help=_(
+            'Enables the ability for a user to change its password '
+            'through self-service APIs'
+        ),
     )
     parser.add_argument(
         '--enable-multi-factor-auth',
@@ -130,11 +174,13 @@ def _add_user_options(parser):
         metavar='<rule>',
         action="append",
         default=[],
-        help=_('Set multi-factor auth rules. For example, to set a rule '
-               'requiring the "password" and "totp" auth methods to be '
-               'provided, use: "--multi-factor-auth-rule password,totp". '
-               'May be provided multiple times to set different rule '
-               'combinations.')
+        help=_(
+            'Set multi-factor auth rules. For example, to set a rule '
+            'requiring the "password" and "totp" auth methods to be '
+            'provided, use: "--multi-factor-auth-rule password,totp". '
+            'May be provided multiple times to set different rule '
+            'combinations.'
+        ),
     )
 
 
@@ -142,7 +188,7 @@ class CreateUser(command.ShowOne):
     _description = _("Create new user")
 
     def get_parser(self, prog_name):
-        parser = super(CreateUser, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'name',
             metavar='<name>',
@@ -201,59 +247,68 @@ class CreateUser(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        identity_client = self.app.client_manager.identity
-
-        project_id = None
-        if parsed_args.project:
-            project_id = common.find_project(identity_client,
-                                             parsed_args.project,
-                                             parsed_args.project_domain).id
+        identity_client = self.app.client_manager.sdk_connection.identity
 
         domain_id = None
         if parsed_args.domain:
-            domain_id = common.find_domain(identity_client,
-                                           parsed_args.domain).id
+            domain_id = identity_client.find_domain(
+                name_or_id=parsed_args.domain,
+                ignore_missing=False,
+            ).id
 
-        enabled = True
+        project_id = None
+        if parsed_args.project:
+            project_id = identity_client.find_project(
+                name_or_id=parsed_args.project,
+                ignore_missing=False,
+                domain_id=domain_id,
+            ).id
+
+        is_enabled = True
         if parsed_args.disable:
-            enabled = False
+            is_enabled = False
         if parsed_args.password_prompt:
             parsed_args.password = utils.get_password(self.app.stdin)
 
         if not parsed_args.password:
-            LOG.warning(_("No password was supplied, authentication will fail "
-                          "when a user does not have a password."))
+            LOG.warning(
+                _(
+                    "No password was supplied, authentication will fail "
+                    "when a user does not have a password."
+                )
+            )
         options = _get_options_for_user(identity_client, parsed_args)
 
         try:
-            user = identity_client.users.create(
-                name=parsed_args.name,
-                domain=domain_id,
-                default_project=project_id,
-                password=parsed_args.password,
-                email=parsed_args.email,
+            user = identity_client.create_user(
+                default_project_id=project_id,
                 description=parsed_args.description,
-                enabled=enabled,
+                domain_id=domain_id,
+                email=parsed_args.email,
+                is_enabled=is_enabled,
+                name=parsed_args.name,
+                password=parsed_args.password,
                 options=options,
             )
-        except ks_exc.Conflict:
+        except sdk_exc.ConflictException:
             if parsed_args.or_show:
-                user = utils.find_resource(identity_client.users,
-                                           parsed_args.name,
-                                           domain_id=domain_id)
+                user = identity_client.find_user(
+                    name_or_id=parsed_args.name,
+                    domain_id=domain_id,
+                    ignore_missing=False,
+                )
                 LOG.info(_('Returning existing user %s'), user.name)
             else:
                 raise
 
-        user._info.pop('links')
-        return zip(*sorted(user._info.items()))
+        return _format_user(user)
 
 
 class DeleteUser(command.Command):
     _description = _("Delete user(s)")
 
     def get_parser(self, prog_name):
-        parser = super(DeleteUser, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'users',
             metavar='<user>',
@@ -268,32 +323,44 @@ class DeleteUser(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        identity_client = self.app.client_manager.identity
+        identity_client = self.app.client_manager.sdk_connection.identity
 
         domain = None
         if parsed_args.domain:
-            domain = common.find_domain(identity_client, parsed_args.domain)
+            domain = identity_client.find_domain(
+                name_or_id=parsed_args.domain,
+                ignore_missing=True,
+            )
         errors = 0
         for user in parsed_args.users:
             try:
                 if domain is not None:
-                    user_obj = utils.find_resource(identity_client.users,
-                                                   user,
-                                                   domain_id=domain.id)
+                    user_obj = identity_client.find_user(
+                        name_or_id=user,
+                        domain_id=domain.id,
+                        ignore_missing=False,
+                    )
                 else:
-                    user_obj = utils.find_resource(identity_client.users,
-                                                   user)
-                identity_client.users.delete(user_obj.id)
+                    user_obj = identity_client.find_user(
+                        name_or_id=user, ignore_missing=False
+                    )
+                identity_client.delete_user(user_obj.id, ignore_missing=False)
             except Exception as e:
                 errors += 1
-                LOG.error(_("Failed to delete user with "
-                          "name or ID '%(user)s': %(e)s"),
-                          {'user': user, 'e': e})
+                LOG.error(
+                    _(
+                        "Failed to delete user with "
+                        "name or ID '%(user)s': %(e)s"
+                    ),
+                    {'user': user, 'e': e},
+                )
 
         if errors > 0:
             total = len(parsed_args.users)
-            msg = (_("%(errors)s of %(total)s users failed "
-                   "to delete.") % {'errors': errors, 'total': total})
+            msg = _("%(errors)s of %(total)s users failed " "to delete.") % {
+                'errors': errors,
+                'total': total,
+            }
             raise exceptions.CommandError(msg)
 
 
@@ -301,7 +368,7 @@ class ListUser(command.Lister):
     _description = _("List users")
 
     def get_parser(self, prog_name):
-        parser = super(ListUser, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             '--domain',
             metavar='<domain>',
@@ -327,73 +394,93 @@ class ListUser(command.Lister):
         return parser
 
     def take_action(self, parsed_args):
-        identity_client = self.app.client_manager.identity
+        identity_client = self.app.client_manager.sdk_connection.identity
 
         domain = None
         if parsed_args.domain:
-            domain = common.find_domain(identity_client,
-                                        parsed_args.domain).id
+            domain = identity_client.find_domain(
+                name_or_id=parsed_args.domain,
+            ).id
 
         group = None
         if parsed_args.group:
-            group = common.find_group(identity_client,
-                                      parsed_args.group,
-                                      parsed_args.domain).id
+            group = identity_client.find_group(
+                name_or_id=parsed_args.group,
+                domain_id=parsed_args.domain,
+                ignore_missing=False,
+            ).id
 
         if parsed_args.project:
             if domain is not None:
-                project = utils.find_resource(
-                    identity_client.projects,
-                    parsed_args.project,
-                    domain_id=domain
+                project = identity_client.find_project(
+                    name_or_id=parsed_args.project,
+                    domain_id=domain,
+                    ignore_missing=False,
                 ).id
             else:
-                project = utils.find_resource(
-                    identity_client.projects,
-                    parsed_args.project,
+                project = identity_client.find_project(
+                    name_or_id=parsed_args.project,
+                    ignore_missing=False,
                 ).id
 
-            assignments = identity_client.role_assignments.list(
-                project=project)
+            assignments = identity_client.role_assignments_filter(
+                project=project
+            )
 
             # NOTE(stevemar): If a user has more than one role on a project
             # then they will have two entries in the returned data. Since we
             # are looking for any role, let's just track unique user IDs.
             user_ids = set()
             for assignment in assignments:
-                if hasattr(assignment, 'user'):
+                if assignment.user:
                     user_ids.add(assignment.user['id'])
 
             # NOTE(stevemar): Call find_resource once we have unique IDs, so
             # it's fewer trips to the Identity API, then collect the data.
             data = []
             for user_id in user_ids:
-                user = utils.find_resource(identity_client.users, user_id)
+                user = identity_client.find_user(user_id, ignore_missing=False)
                 data.append(user)
 
-        else:
-            data = identity_client.users.list(
-                domain=domain,
+        elif parsed_args.group:
+            data = identity_client.group_users(
+                domain_id=domain,
                 group=group,
             )
+        else:
+            data = identity_client.users(
+                domain_id=domain,
+            )
 
         # Column handling
         if parsed_args.long:
-            columns = ['ID', 'Name', 'Default Project Id', 'Domain Id',
-                       'Description', 'Email', 'Enabled']
+            columns = [
+                'ID',
+                'Name',
+                'Default Project Id',
+                'Domain Id',
+                'Description',
+                'Email',
+                'Is Enabled',
+            ]
             column_headers = copy.deepcopy(columns)
             column_headers[2] = 'Project'
             column_headers[3] = 'Domain'
+            column_headers[6] = 'Enabled'
         else:
             columns = ['ID', 'Name']
             column_headers = columns
 
         return (
             column_headers,
-            (utils.get_item_properties(
-                s, columns,
-                formatters={},
-            ) for s in data)
+            (
+                utils.get_item_properties(
+                    s,
+                    columns,
+                    formatters={},
+                )
+                for s in data
+            ),
         )
 
 
@@ -401,7 +488,7 @@ class SetUser(command.Command):
     _description = _("Set user properties")
 
     def get_parser(self, prog_name):
-        parser = super(SetUser, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'user',
             metavar='<user>',
@@ -415,8 +502,10 @@ class SetUser(command.Command):
         parser.add_argument(
             '--domain',
             metavar='<domain>',
-            help=_('Domain the user belongs to (name or ID). This can be '
-                   'used in case collisions between user names exist.'),
+            help=_(
+                'Domain the user belongs to (name or ID). This can be '
+                'used in case collisions between user names exist.'
+            ),
         )
         parser.add_argument(
             '--project',
@@ -461,27 +550,36 @@ class SetUser(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        identity_client = self.app.client_manager.identity
+        identity_client = self.app.client_manager.sdk_connection.identity
 
         if parsed_args.password_prompt:
             parsed_args.password = utils.get_password(self.app.stdin)
 
         if '' == parsed_args.password:
-            LOG.warning(_("No password was supplied, authentication will fail "
-                          "when a user does not have a password."))
+            LOG.warning(
+                _(
+                    "No password was supplied, authentication will fail "
+                    "when a user does not have a password."
+                )
+            )
 
-        user_str = common._get_token_resource(identity_client, 'user',
-                                              parsed_args.user,
-                                              parsed_args.domain)
+        user_str = common._get_token_resource(
+            identity_client, 'user', parsed_args.user, parsed_args.domain
+        )
         if parsed_args.domain:
-            domain = common.find_domain(identity_client, parsed_args.domain)
-            user = utils.find_resource(identity_client.users,
-                                       user_str,
-                                       domain_id=domain.id)
+            domain = identity_client.find_domain(
+                name_or_id=parsed_args.domain,
+                ignore_missing=False,
+            )
+            user = identity_client.find_user(
+                name_or_id=user_str,
+                domain_id=domain.id,
+                ignore_missing=False,
+            )
         else:
-            user = utils.find_resource(
-                identity_client.users,
-                parsed_args.user,
+            user = identity_client.find_user(
+                name_or_id=parsed_args.user,
+                ignore_missing=False,
             )
 
         kwargs = {}
@@ -494,21 +592,27 @@ class SetUser(command.Command):
         if parsed_args.description:
             kwargs['description'] = parsed_args.description
         if parsed_args.project:
-            project_id = common.find_project(identity_client,
-                                             parsed_args.project,
-                                             parsed_args.project_domain).id
-            kwargs['default_project'] = project_id
-        kwargs['enabled'] = user.enabled
+            project_domain_id = identity_client.find_domain(
+                name_or_id=parsed_args.project_domain,
+                ignore_missing=False,
+            ).id
+            project_id = identity_client.find_project(
+                name_or_id=parsed_args.project,
+                ignore_missing=False,
+                domain_id=project_domain_id,
+            ).id
+            kwargs['default_project_id'] = project_id
+        kwargs['is_enabled'] = user.is_enabled
         if parsed_args.enable:
-            kwargs['enabled'] = True
+            kwargs['is_enabled'] = True
         if parsed_args.disable:
-            kwargs['enabled'] = False
+            kwargs['is_enabled'] = False
 
         options = _get_options_for_user(identity_client, parsed_args)
         if options:
             kwargs['options'] = options
 
-        identity_client.users.update(user.id, **kwargs)
+        identity_client.update_user(user=user, **kwargs)
 
 
 class SetPasswordUser(command.Command):
@@ -517,7 +621,7 @@ class SetPasswordUser(command.Command):
     required_scope = False
 
     def get_parser(self, prog_name):
-        parser = super(SetPasswordUser, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             '--password',
             metavar='<new-password>',
@@ -531,7 +635,7 @@ class SetPasswordUser(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        identity_client = self.app.client_manager.identity
+        identity_client = self.app.client_manager.sdk_connection.identity
 
         # FIXME(gyee): there are two scenarios:
         #
@@ -556,25 +660,33 @@ class SetPasswordUser(command.Command):
         current_password = parsed_args.original_password
         if current_password is None:
             current_password = utils.get_password(
-                self.app.stdin, prompt="Current Password:", confirm=False)
+                self.app.stdin, prompt="Current Password:", confirm=False
+            )
 
         password = parsed_args.password
         if password is None:
             password = utils.get_password(
-                self.app.stdin, prompt="New Password:")
+                self.app.stdin, prompt="New Password:"
+            )
 
         if '' == password:
-            LOG.warning(_("No password was supplied, authentication will fail "
-                          "when a user does not have a password."))
+            LOG.warning(
+                _(
+                    "No password was supplied, authentication will fail "
+                    "when a user does not have a password."
+                )
+            )
 
-        identity_client.users.update_password(current_password, password)
+        identity_client.update_user(
+            current_password=current_password, password=password
+        )
 
 
 class ShowUser(command.ShowOne):
     _description = _("Display user details")
 
     def get_parser(self, prog_name):
-        parser = super(ShowUser, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'user',
             metavar='<user>',
@@ -588,19 +700,28 @@ class ShowUser(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        identity_client = self.app.client_manager.identity
+        identity_client = self.app.client_manager.sdk_connection.identity
 
-        user_str = common._get_token_resource(identity_client, 'user',
-                                              parsed_args.user,
-                                              parsed_args.domain)
+        user_str = common._get_token_resource(
+            identity_client, 'user', parsed_args.user, parsed_args.domain
+        )
+
+        domain = None
         if parsed_args.domain:
-            domain = common.find_domain(identity_client, parsed_args.domain)
-            user = utils.find_resource(identity_client.users,
-                                       user_str,
-                                       domain_id=domain.id)
+            domain = identity_client.find_domain(
+                name_or_id=parsed_args.domain,
+                ignore_missing=True,
+            )
+        if domain:
+            user = identity_client.find_user(
+                name_or_id=user_str,
+                domain_id=domain.id,
+                ignore_missing=False,
+            )
         else:
-            user = utils.find_resource(identity_client.users,
-                                       user_str)
+            user = identity_client.find_user(
+                name_or_id=user_str,
+                ignore_missing=False,
+            )
 
-        user._info.pop('links')
-        return zip(*sorted(user._info.items()))
+        return _format_user(user)
