@@ -32,7 +32,7 @@ class IdentityProviderTests(common.IdentityTests):
         idp_1 = self._create_dummy_idp(add_clean_up=False)
         idp_2 = self._create_dummy_idp(add_clean_up=False)
         raw_output = self.openstack(
-            'identity provider delete %s %s' % (idp_1, idp_2)
+            f'identity provider delete {idp_1} {idp_2}'
         )
         self.assertEqual(0, len(raw_output))
 
