@@ -20,12 +20,6 @@ class RouterTests(common.NetworkTagTests):
 
     base_command = 'router'
 
-    def setUp(self):
-        super(RouterTests, self).setUp()
-        # Nothing in this class works with Nova Network
-        if not self.haz_network:
-            self.skipTest("No Network service present")
-
     def test_router_create_and_delete(self):
         """Test create options, delete multiple"""
         name1 = uuid.uuid4().hex
@@ -293,10 +287,10 @@ class RouterTests(common.NetworkTagTests):
         self.openstack('router create %s' % router_name)
         self.addCleanup(self.openstack, 'router delete %s' % router_name)
 
-        self.openstack('router add subnet %s %s' % (router_name, subnet_name))
+        self.openstack(f'router add subnet {router_name} {subnet_name}')
         self.addCleanup(
             self.openstack,
-            'router remove subnet %s %s' % (router_name, subnet_name),
+            f'router remove subnet {router_name} {subnet_name}',
         )
 
         out1 = (
