@@ -15,10 +15,11 @@
 
 import copy
 import random
+import re
 from unittest import mock
 import uuid
 
-from novaclient import api_versions
+from keystoneauth1 import discover
 from openstack.compute.v2 import _proxy
 from openstack.compute.v2 import aggregate as _aggregate
 from openstack.compute.v2 import availability_zone as _availability_zone
@@ -26,6 +27,7 @@ from openstack.compute.v2 import extension as _extension
 from openstack.compute.v2 import flavor as _flavor
 from openstack.compute.v2 import hypervisor as _hypervisor
 from openstack.compute.v2 import keypair as _keypair
+from openstack.compute.v2 import limits as _limits
 from openstack.compute.v2 import migration as _migration
 from openstack.compute.v2 import server as _server
 from openstack.compute.v2 import server_action as _server_action
@@ -36,7 +38,6 @@ from openstack.compute.v2 import service as _service
 from openstack.compute.v2 import usage as _usage
 from openstack.compute.v2 import volume_attachment as _volume_attachment
 
-from openstackclient.api import compute_v2
 from openstackclient.tests.unit import fakes
 from openstackclient.tests.unit.identity.v2_0 import fakes as identity_fakes
 from openstackclient.tests.unit.image.v2 import fakes as image_fakes
@@ -44,44 +45,8 @@ from openstackclient.tests.unit.network.v2 import fakes as network_fakes
 from openstackclient.tests.unit import utils
 from openstackclient.tests.unit.volume.v3 import fakes as volume_fakes
 
-floating_ip_num = 100
-fix_ip_num = 100
-injected_file_num = 100
-injected_file_size_num = 10240
-injected_path_size_num = 255
-key_pair_num = 100
-core_num = 20
-ram_num = 51200
-instance_num = 10
-property_num = 128
-secgroup_rule_num = 20
-secgroup_num = 10
-servgroup_num = 10
-servgroup_members_num = 10
-project_name = 'project_test'
-QUOTA = {
-    'project': project_name,
-    'floating-ips': floating_ip_num,
-    'fix-ips': fix_ip_num,
-    'injected-files': injected_file_num,
-    'injected-file-size': injected_file_size_num,
-    'injected-path-size': injected_path_size_num,
-    'key-pairs': key_pair_num,
-    'cores': core_num,
-    'ram': ram_num,
-    'instances': instance_num,
-    'properties': property_num,
-    'secgroup_rules': secgroup_rule_num,
-    'secgroups': secgroup_num,
-    'server-groups': servgroup_num,
-    'server-group-members': servgroup_members_num,
-}
 
-QUOTA_columns = tuple(sorted(QUOTA))
-QUOTA_data = tuple(QUOTA[x] for x in sorted(QUOTA))
-
-
-class FakeComputev2Client(object):
+class FakeComputev2Client:
     def __init__(self, **kwargs):
         self.agents = mock.Mock()
         self.agents.resource_class = fakes.FakeResource(None, {})
@@ -89,9 +54,6 @@ class FakeComputev2Client(object):
         self.images = mock.Mock()
         self.images.resource_class = fakes.FakeResource(None, {})
 
-        self.limits = mock.Mock()
-        self.limits.resource_class = fakes.FakeResource(None, {})
-
         self.servers = mock.Mock()
         self.servers.resource_class = fakes.FakeResource(None, {})
 
@@ -106,12 +68,6 @@ class FakeComputev2Client(object):
         self.flavor_access = mock.Mock()
         self.flavor_access.resource_class = fakes.FakeResource(None, {})
 
-        self.quotas = mock.Mock()
-        self.quotas.resource_class = fakes.FakeResource(None, {})
-
-        self.quota_classes = mock.Mock()
-        self.quota_classes.resource_class = fakes.FakeResource(None, {})
-
         self.usage = mock.Mock()
         self.usage.resource_class = fakes.FakeResource(None, {})
 
@@ -127,9 +83,6 @@ class FakeComputev2Client(object):
         self.keypairs = mock.Mock()
         self.keypairs.resource_class = fakes.FakeResource(None, {})
 
-        self.hosts = mock.Mock()
-        self.hosts.resource_class = fakes.FakeResource(None, {})
-
         self.server_groups = mock.Mock()
         self.server_groups.resource_class = fakes.FakeResource(None, {})
 
@@ -146,24 +99,11 @@ class FakeComputev2Client(object):
 
         self.management_url = kwargs['endpoint']
 
-        self.api_version = api_versions.APIVersion('2.1')
-
 
 class FakeClientMixin:
     def setUp(self):
         super().setUp()
 
-        self.app.client_manager.compute = FakeComputev2Client(
-            endpoint=fakes.AUTH_URL,
-            token=fakes.AUTH_TOKEN,
-        )
-        self.compute_client = self.app.client_manager.compute
-
-        self.compute_client.api = compute_v2.APIv2(
-            session=self.app.client_manager.session,
-            endpoint=fakes.AUTH_URL,
-        )
-
         # TODO(stephenfin): Rename to 'compute_client' once all commands are
         # migrated to SDK
         self.app.client_manager.sdk_connection.compute = mock.Mock(
@@ -172,22 +112,34 @@ class FakeClientMixin:
         self.compute_sdk_client = (
             self.app.client_manager.sdk_connection.compute
         )
+        self.set_compute_api_version()  # default to the lowest
+
+    def set_compute_api_version(self, version: str = '2.1'):
+        """Set a fake server version.
+
+        :param version: The fake microversion to "support". This should be a
+            string of format '2.xx'.
+        :returns: None
+        """
+        assert re.match(r'2.\d+', version)
+
+        self.compute_sdk_client.default_microversion = version
+        self.compute_sdk_client.get_endpoint_data.return_value = (
+            discover.EndpointData(
+                min_microversion='2.1',  # nova has not bumped this yet
+                max_microversion=version,
+            )
+        )
 
 
 class TestComputev2(
     network_fakes.FakeClientMixin,
     image_fakes.FakeClientMixin,
     volume_fakes.FakeClientMixin,
+    identity_fakes.FakeClientMixin,
     FakeClientMixin,
     utils.TestCommand,
-):
-    def setUp(self):
-        super().setUp()
-
-        self.app.client_manager.identity = identity_fakes.FakeIdentityv2Client(
-            endpoint=fakes.AUTH_URL,
-            token=fakes.AUTH_TOKEN,
-        )
+): ...
 
 
 def create_one_aggregate(attrs=None):
@@ -1018,56 +970,6 @@ def get_networks(networks=None, count=2):
     return mock.Mock(side_effect=networks)
 
 
-def create_one_host(attrs=None):
-    """Create a fake host.
-
-    :param dict attrs:
-        A dictionary with all attributes
-    :return:
-        A FakeResource object, with uuid and other attributes
-    """
-    attrs = attrs or {}
-
-    # Set default attributes.
-    host_info = {
-        "service_id": 1,
-        "host": "host1",
-        "uuid": 'host-id-' + uuid.uuid4().hex,
-        "vcpus": 10,
-        "memory_mb": 100,
-        "local_gb": 100,
-        "vcpus_used": 5,
-        "memory_mb_used": 50,
-        "local_gb_used": 10,
-        "hypervisor_type": "xen",
-        "hypervisor_version": 1,
-        "hypervisor_hostname": "devstack1",
-        "free_ram_mb": 50,
-        "free_disk_gb": 50,
-        "current_workload": 10,
-        "running_vms": 1,
-        "cpu_info": "",
-        "disk_available_least": 1,
-        "host_ip": "10.10.10.10",
-        "supported_instances": "",
-        "metrics": "",
-        "pci_stats": "",
-        "extra_resources": "",
-        "stats": "",
-        "numa_topology": "",
-        "ram_allocation_ratio": 1.0,
-        "cpu_allocation_ratio": 1.0,
-        "zone": 'zone-' + uuid.uuid4().hex,
-        "host_name": 'name-' + uuid.uuid4().hex,
-        "service": 'service-' + uuid.uuid4().hex,
-        "cpu": 4,
-        "disk_gb": 100,
-        'project': 'project-' + uuid.uuid4().hex,
-    }
-    host_info.update(attrs)
-    return host_info
-
-
 def create_one_usage(attrs=None):
     """Create a fake usage.
 
@@ -1124,103 +1026,12 @@ def create_usages(attrs=None, count=2):
     return usages
 
 
-def create_one_comp_quota(attrs=None):
-    """Create one quota"""
-
+def create_limits(attrs=None):
+    """Create a fake limits object."""
     attrs = attrs or {}
 
-    quota_attrs = {
-        'id': 'project-id-' + uuid.uuid4().hex,
-        'cores': 20,
-        'fixed_ips': 30,
-        'injected_files': 100,
-        'injected_file_content_bytes': 10240,
-        'injected_file_path_bytes': 255,
-        'instances': 50,
-        'key_pairs': 20,
-        'metadata_items': 10,
-        'ram': 51200,
-        'server_groups': 10,
-        'server_group_members': 10,
-    }
-
-    quota_attrs.update(attrs)
-    quota = fakes.FakeResource(info=copy.deepcopy(quota_attrs), loaded=True)
-
-    quota.project_id = quota_attrs['id']
-
-    return quota
-
-
-def create_one_default_comp_quota(attrs=None):
-    """Create one quota"""
-
-    attrs = attrs or {}
-
-    quota_attrs = {
-        'id': 'project-id-' + uuid.uuid4().hex,
-        'cores': 10,
-        'fixed_ips': 10,
-        'injected_files': 100,
-        'injected_file_content_bytes': 10240,
-        'injected_file_path_bytes': 255,
-        'instances': 20,
-        'key_pairs': 20,
-        'metadata_items': 10,
-        'ram': 51200,
-        'server_groups': 10,
-        'server_group_members': 10,
-    }
-
-    quota_attrs.update(attrs)
-    quota = fakes.FakeResource(info=copy.deepcopy(quota_attrs), loaded=True)
-
-    quota.project_id = quota_attrs['id']
-
-    return quota
-
-
-def create_one_comp_detailed_quota(attrs=None):
-    """Create one quota"""
-
-    attrs = attrs or {}
-
-    quota_attrs = {
-        'id': 'project-id-' + uuid.uuid4().hex,
-        'cores': {'reserved': 0, 'in_use': 0, 'limit': 20},
-        'fixed_ips': {'reserved': 0, 'in_use': 0, 'limit': 30},
-        'injected_files': {'reserved': 0, 'in_use': 0, 'limit': 100},
-        'injected_file_content_bytes': {
-            'reserved': 0,
-            'in_use': 0,
-            'limit': 10240,
-        },
-        'injected_file_path_bytes': {
-            'reserved': 0,
-            'in_use': 0,
-            'limit': 255,
-        },
-        'instances': {'reserved': 0, 'in_use': 0, 'limit': 50},
-        'key_pairs': {'reserved': 0, 'in_use': 0, 'limit': 20},
-        'metadata_items': {'reserved': 0, 'in_use': 0, 'limit': 10},
-        'ram': {'reserved': 0, 'in_use': 0, 'limit': 51200},
-        'server_groups': {'reserved': 0, 'in_use': 0, 'limit': 10},
-        'server_group_members': {'reserved': 0, 'in_use': 0, 'limit': 10},
-    }
-
-    quota_attrs.update(attrs)
-    quota = fakes.FakeResource(info=copy.deepcopy(quota_attrs), loaded=True)
-
-    quota.project_id = quota_attrs['id']
-
-    return quota
-
-
-class FakeLimits(object):
-    """Fake limits"""
-
-    def __init__(self, absolute_attrs=None, rate_attrs=None):
-        self.absolute_limits_attrs = {
+    limits_attrs = {
+        'absolute': {
             'maxServerMeta': 128,
             'maxTotalInstances': 10,
             'maxPersonality': 5,
@@ -1240,11 +1051,8 @@ class FakeLimits(object):
             'maxTotalFloatingIps': 10,
             'totalSecurityGroupsUsed': 0,
             'maxTotalCores': 20,
-        }
-        absolute_attrs = absolute_attrs or {}
-        self.absolute_limits_attrs.update(absolute_attrs)
-
-        self.rate_limits_attrs = [
+        },
+        'rate': [
             {
                 "uri": "*",
                 "limit": [
@@ -1271,69 +1079,12 @@ class FakeLimits(object):
                     },
                 ],
             }
-        ]
+        ],
+    }
+    limits_attrs.update(attrs)
 
-    @property
-    def absolute(self):
-        for name, value in self.absolute_limits_attrs.items():
-            yield FakeAbsoluteLimit(name, value)
-
-    def absolute_limits(self):
-        reference_data = []
-        for name, value in self.absolute_limits_attrs.items():
-            reference_data.append((name, value))
-        return reference_data
-
-    @property
-    def rate(self):
-        for group in self.rate_limits_attrs:
-            uri = group['uri']
-            for rate in group['limit']:
-                yield FakeRateLimit(
-                    rate['verb'],
-                    uri,
-                    rate['value'],
-                    rate['remaining'],
-                    rate['unit'],
-                    rate['next-available'],
-                )
-
-    def rate_limits(self):
-        reference_data = []
-        for group in self.rate_limits_attrs:
-            uri = group['uri']
-            for rate in group['limit']:
-                reference_data.append(
-                    (
-                        rate['verb'],
-                        uri,
-                        rate['value'],
-                        rate['remaining'],
-                        rate['unit'],
-                        rate['next-available'],
-                    )
-                )
-        return reference_data
-
-
-class FakeAbsoluteLimit(object):
-    """Data model that represents an absolute limit"""
-
-    def __init__(self, name, value):
-        self.name = name
-        self.value = value
-
-
-class FakeRateLimit(object):
-    """Data model that represents a flattened view of a single rate limit"""
-
-    def __init__(self, verb, uri, value, remain, unit, next_available):
-        self.verb = verb
-        self.uri = uri
-        self.value = value
-        self.remain = remain
-        self.unit = unit
-        self.next_available = next_available
+    limits = _limits.Limits(**limits_attrs)
+    return limits
 
 
 def create_one_migration(attrs=None):
