@@ -17,7 +17,6 @@ from unittest import mock
 from unittest.mock import call
 import uuid
 
-from openstack import utils as sdk_utils
 from osc_lib import exceptions
 
 from openstackclient.compute.v2 import keypair
@@ -29,10 +28,10 @@ from openstackclient.tests.unit import utils as tests_utils
 
 class TestKeypair(compute_fakes.TestComputev2):
     def setUp(self):
-        super(TestKeypair, self).setUp()
+        super().setUp()
 
         # Initialize the user mock
-        self.users_mock = self.app.client_manager.identity.users
+        self.users_mock = self.identity_client.users
         self.users_mock.reset_mock()
         self.users_mock.get.return_value = fakes.FakeResource(
             None,
@@ -118,7 +117,9 @@ class TestKeypairCreate(TestKeypair):
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        with mock.patch('io.open') as mock_open:
+        with mock.patch(
+            'openstackclient.compute.v2.keypair.open'
+        ) as mock_open:
             mock_open.return_value = mock.MagicMock()
             m_file = mock_open.return_value.__enter__.return_value
             m_file.read.return_value = 'dummy'
@@ -152,7 +153,9 @@ class TestKeypairCreate(TestKeypair):
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        with mock.patch('io.open') as mock_open:
+        with mock.patch(
+            'openstackclient.compute.v2.keypair.open'
+        ) as mock_open:
             mock_open.return_value = mock.MagicMock()
             m_file = mock_open.return_value.__enter__.return_value
 
@@ -171,8 +174,9 @@ class TestKeypairCreate(TestKeypair):
             self.assertEqual(self.columns, columns)
             self.assertEqual(self.data, data)
 
-    @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
-    def test_keypair_create_with_key_type(self, sm_mock):
+    def test_keypair_create_with_key_type(self):
+        self.set_compute_api_version('2.2')
+
         for key_type in ['x509', 'ssh']:
             self.compute_sdk_client.create_keypair.return_value = self.keypair
 
@@ -199,7 +203,9 @@ class TestKeypairCreate(TestKeypair):
             ]
             parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-            with mock.patch('io.open') as mock_open:
+            with mock.patch(
+                'openstackclient.compute.v2.keypair.open'
+            ) as mock_open:
                 mock_open.return_value = mock.MagicMock()
                 m_file = mock_open.return_value.__enter__.return_value
                 m_file.read.return_value = 'dummy'
@@ -214,8 +220,9 @@ class TestKeypairCreate(TestKeypair):
             self.assertEqual(self.columns, columns)
             self.assertEqual(self.data, data)
 
-    @mock.patch.object(sdk_utils, 'supports_microversion', return_value=False)
-    def test_keypair_create_with_key_type_pre_v22(self, sm_mock):
+    def test_keypair_create_with_key_type_pre_v22(self):
+        self.set_compute_api_version('2.1')
+
         for key_type in ['x509', 'ssh']:
             arglist = [
                 '--public-key',
@@ -231,7 +238,9 @@ class TestKeypairCreate(TestKeypair):
             ]
             parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-            with mock.patch('io.open') as mock_open:
+            with mock.patch(
+                'openstackclient.compute.v2.keypair.open'
+            ) as mock_open:
                 mock_open.return_value = mock.MagicMock()
                 m_file = mock_open.return_value.__enter__.return_value
                 m_file.read.return_value = 'dummy'
@@ -249,8 +258,9 @@ class TestKeypairCreate(TestKeypair):
         '_generate_keypair',
         return_value=keypair.Keypair('private', 'public'),
     )
-    @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
-    def test_key_pair_create_with_user(self, sm_mock, mock_generate):
+    def test_key_pair_create_with_user(self, mock_generate):
+        self.set_compute_api_version('2.10')
+
         arglist = [
             '--user',
             identity_fakes.user_name,
@@ -273,8 +283,9 @@ class TestKeypairCreate(TestKeypair):
         self.assertEqual({}, columns)
         self.assertEqual({}, data)
 
-    @mock.patch.object(sdk_utils, 'supports_microversion', return_value=False)
-    def test_key_pair_create_with_user_pre_v210(self, sm_mock):
+    def test_key_pair_create_with_user_pre_v210(self):
+        self.set_compute_api_version('2.9')
+
         arglist = [
             '--user',
             identity_fakes.user_name,
@@ -360,8 +371,9 @@ class TestKeypairDelete(TestKeypair):
             calls.append(call(k, ignore_missing=False))
         self.compute_sdk_client.delete_keypair.assert_has_calls(calls)
 
-    @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
-    def test_keypair_delete_with_user(self, sm_mock):
+    def test_keypair_delete_with_user(self):
+        self.set_compute_api_version('2.10')
+
         arglist = ['--user', identity_fakes.user_name, self.keypairs[0].name]
         verifylist = [
             ('user', identity_fakes.user_name),
@@ -378,8 +390,9 @@ class TestKeypairDelete(TestKeypair):
             ignore_missing=False,
         )
 
-    @mock.patch.object(sdk_utils, 'supports_microversion', return_value=False)
-    def test_keypair_delete_with_user_pre_v210(self, sm_mock):
+    def test_keypair_delete_with_user_pre_v210(self):
+        self.set_compute_api_version('2.9')
+
         arglist = ['--user', identity_fakes.user_name, self.keypairs[0].name]
         verifylist = [
             ('user', identity_fakes.user_name),
@@ -407,8 +420,7 @@ class TestKeypairList(TestKeypair):
         # Get the command object to test
         self.cmd = keypair.ListKeypair(self.app, None)
 
-    @mock.patch.object(sdk_utils, 'supports_microversion', return_value=False)
-    def test_keypair_list_no_options(self, sm_mock):
+    def test_keypair_list_no_options(self):
         arglist = []
         verifylist = []
 
@@ -429,8 +441,9 @@ class TestKeypairList(TestKeypair):
             tuple(data),
         )
 
-    @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
-    def test_keypair_list_v22(self, sm_mock):
+    def test_keypair_list_v22(self):
+        self.set_compute_api_version('2.22')
+
         arglist = []
         verifylist = []
 
@@ -457,9 +470,10 @@ class TestKeypairList(TestKeypair):
             tuple(data),
         )
 
-    @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
-    def test_keypair_list_with_user(self, sm_mock):
-        users_mock = self.app.client_manager.identity.users
+    def test_keypair_list_with_user(self):
+        self.set_compute_api_version('2.35')
+
+        users_mock = self.identity_client.users
         users_mock.reset_mock()
         users_mock.get.return_value = fakes.FakeResource(
             None,
@@ -495,8 +509,9 @@ class TestKeypairList(TestKeypair):
             tuple(data),
         )
 
-    @mock.patch.object(sdk_utils, 'supports_microversion', return_value=False)
-    def test_keypair_list_with_user_pre_v210(self, sm_mock):
+    def test_keypair_list_with_user_pre_v210(self):
+        self.set_compute_api_version('2.9')
+
         arglist = [
             '--user',
             identity_fakes.user_name,
@@ -513,9 +528,10 @@ class TestKeypairList(TestKeypair):
             '--os-compute-api-version 2.10 or greater is required', str(ex)
         )
 
-    @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
-    def test_keypair_list_with_project(self, sm_mock):
-        projects_mock = self.app.client_manager.identity.tenants
+    def test_keypair_list_with_project(self):
+        self.set_compute_api_version('2.35')
+
+        projects_mock = self.identity_client.tenants
         projects_mock.reset_mock()
         projects_mock.get.return_value = fakes.FakeResource(
             None,
@@ -523,7 +539,7 @@ class TestKeypairList(TestKeypair):
             loaded=True,
         )
 
-        users_mock = self.app.client_manager.identity.users
+        users_mock = self.identity_client.users
         users_mock.reset_mock()
         users_mock.list.return_value = [
             fakes.FakeResource(
@@ -557,8 +573,9 @@ class TestKeypairList(TestKeypair):
             tuple(data),
         )
 
-    @mock.patch.object(sdk_utils, 'supports_microversion', return_value=False)
-    def test_keypair_list_with_project_pre_v210(self, sm_mock):
+    def test_keypair_list_with_project_pre_v210(self):
+        self.set_compute_api_version('2.9')
+
         arglist = ['--project', identity_fakes.project_name]
         verifylist = [('project', identity_fakes.project_name)]
 
@@ -586,10 +603,9 @@ class TestKeypairList(TestKeypair):
             None,
         )
 
-    @mock.patch.object(
-        sdk_utils, 'supports_microversion', new=mock.Mock(return_value=True)
-    )
     def test_keypair_list_with_limit(self):
+        self.set_compute_api_version('2.35')
+
         arglist = [
             '--limit',
             '1',
@@ -603,10 +619,9 @@ class TestKeypairList(TestKeypair):
 
         self.compute_sdk_client.keypairs.assert_called_with(limit=1)
 
-    @mock.patch.object(
-        sdk_utils, 'supports_microversion', new=mock.Mock(return_value=False)
-    )
     def test_keypair_list_with_limit_pre_v235(self):
+        self.set_compute_api_version('2.34')
+
         arglist = [
             '--limit',
             '1',
@@ -624,10 +639,9 @@ class TestKeypairList(TestKeypair):
             '--os-compute-api-version 2.35 or greater is required', str(ex)
         )
 
-    @mock.patch.object(
-        sdk_utils, 'supports_microversion', new=mock.Mock(return_value=True)
-    )
     def test_keypair_list_with_marker(self):
+        self.set_compute_api_version('2.35')
+
         arglist = [
             '--marker',
             'test_kp',
@@ -641,10 +655,9 @@ class TestKeypairList(TestKeypair):
 
         self.compute_sdk_client.keypairs.assert_called_with(marker='test_kp')
 
-    @mock.patch.object(
-        sdk_utils, 'supports_microversion', new=mock.Mock(return_value=False)
-    )
     def test_keypair_list_with_marker_pre_v235(self):
+        self.set_compute_api_version('2.34')
+
         arglist = [
             '--marker',
             'test_kp',
@@ -735,8 +748,9 @@ class TestKeypairShow(TestKeypair):
         self.assertEqual({}, columns)
         self.assertEqual({}, data)
 
-    @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
-    def test_keypair_show_with_user(self, sm_mock):
+    def test_keypair_show_with_user(self):
+        self.set_compute_api_version('2.10')
+
         self.keypair = compute_fakes.create_one_keypair()
         self.compute_sdk_client.find_keypair.return_value = self.keypair
 
@@ -774,8 +788,9 @@ class TestKeypairShow(TestKeypair):
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
 
-    @mock.patch.object(sdk_utils, 'supports_microversion', return_value=False)
-    def test_keypair_show_with_user_pre_v210(self, sm_mock):
+    def test_keypair_show_with_user_pre_v210(self):
+        self.set_compute_api_version('2.9')
+
         self.keypair = compute_fakes.create_one_keypair()
         arglist = [
             '--user',
