@@ -47,7 +47,7 @@ class TestCatalog(utils.TestCommand):
     }
 
     def setUp(self):
-        super(TestCatalog, self).setUp()
+        super().setUp()
 
         self.sc_mock = mock.Mock()
         self.sc_mock.service_catalog.catalog.return_value = [
@@ -62,7 +62,7 @@ class TestCatalog(utils.TestCommand):
 
 class TestCatalogList(TestCatalog):
     def setUp(self):
-        super(TestCatalogList, self).setUp()
+        super().setUp()
 
         # Get the command object to test
         self.cmd = catalog.ListCatalog(self.app, None)
@@ -100,7 +100,7 @@ class TestCatalogList(TestCatalog):
 
 class TestCatalogShow(TestCatalog):
     def setUp(self):
-        super(TestCatalogShow, self).setUp()
+        super().setUp()
 
         # Get the command object to test
         self.cmd = catalog.ShowCatalog(self.app, None)
