@@ -30,7 +30,7 @@ from openstackclient.tests.unit import utils as tests_utils
 
 class TestDefaultSecurityGroupRule(network_fakes.TestNetworkV2):
     def setUp(self):
-        super(TestDefaultSecurityGroupRule, self).setUp()
+        super().setUp()
 
         self.app.client_manager.sdk_connection = mock.Mock()
         self.app.client_manager.sdk_connection.network = mock.Mock(
@@ -72,7 +72,7 @@ class TestCreateDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
             'remote_ip_prefix': '0.0.0.0/0',
             'location': 'MUNCHMUNCHMUNCH',
             'used_in_default_sg': False,
-            'used_in_non_default_sg': True,
+            'used_in_non_default_sg': False,
         }
         attrs = attrs or {}
         # Overwrite default attributes.
@@ -101,11 +101,11 @@ class TestCreateDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
         )
 
     def setUp(self):
-        super(TestCreateDefaultSecurityGroupRule, self).setUp()
+        super().setUp()
 
         # Get the command object to test
         self.cmd = default_security_group_rule.CreateDefaultSecurityGroupRule(
-            self.app, self.namespace
+            self.app, None
         )
 
     def test_create_all_remote_options(self):
@@ -217,13 +217,15 @@ class TestCreateDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
                 'protocol': self._default_sg_rule.protocol,
                 'remote_ip_prefix': self._default_sg_rule.remote_ip_prefix,
                 'used_in_default_sg': False,
-                'used_in_non_default_sg': True,
+                'used_in_non_default_sg': False,
             }
         )
         self.assertEqual(self.expected_columns, columns)
         self.assertEqual(self.expected_data, data)
 
-    def test_create_protocol_any(self):
+    def _test_create_protocol_any_helper(
+        self, for_default_sg=False, for_custom_sg=False
+    ):
         self._setup_default_security_group_rule(
             {
                 'protocol': None,
@@ -236,9 +238,15 @@ class TestCreateDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
             '--remote-ip',
             self._default_sg_rule.remote_ip_prefix,
         ]
+        if for_default_sg:
+            arglist.append('--for-default-sg')
+        if for_custom_sg:
+            arglist.append('--for-custom-sg')
         verifylist = [
             ('protocol', 'any'),
             ('remote_ip', self._default_sg_rule.remote_ip_prefix),
+            ('for_default_sg', for_default_sg),
+            ('for_custom_sg', for_custom_sg),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -250,13 +258,27 @@ class TestCreateDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
                 'ethertype': self._default_sg_rule.ether_type,
                 'protocol': self._default_sg_rule.protocol,
                 'remote_ip_prefix': self._default_sg_rule.remote_ip_prefix,
-                'used_in_default_sg': False,
-                'used_in_non_default_sg': True,
+                'used_in_default_sg': for_default_sg,
+                'used_in_non_default_sg': for_custom_sg,
             }
         )
         self.assertEqual(self.expected_columns, columns)
         self.assertEqual(self.expected_data, data)
 
+    def test_create_protocol_any_not_for_default_sg(self):
+        self._test_create_protocol_any_helper()
+
+    def test_create_protocol_any_for_default_sg(self):
+        self._test_create_protocol_any_helper(for_default_sg=True)
+
+    def test_create_protocol_any_for_custom_sg(self):
+        self._test_create_protocol_any_helper(for_custom_sg=True)
+
+    def test_create_protocol_any_for_default_and_custom_sg(self):
+        self._test_create_protocol_any_helper(
+            for_default_sg=True, for_custom_sg=True
+        )
+
     def test_create_remote_address_group(self):
         self._setup_default_security_group_rule(
             {
@@ -287,7 +309,7 @@ class TestCreateDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
                 'protocol': self._default_sg_rule.protocol,
                 'remote_address_group_id': self._default_sg_rule.remote_address_group_id,
                 'used_in_default_sg': False,
-                'used_in_non_default_sg': True,
+                'used_in_non_default_sg': False,
             }
         )
         self.assertEqual(self.expected_columns, columns)
@@ -334,7 +356,7 @@ class TestCreateDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
                 'protocol': self._default_sg_rule.protocol,
                 'remote_group_id': 'remote-group-id',
                 'used_in_default_sg': False,
-                'used_in_non_default_sg': True,
+                'used_in_non_default_sg': False,
             }
         )
         self.assertEqual(self.expected_columns, columns)
@@ -366,7 +388,7 @@ class TestCreateDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
                 'protocol': self._default_sg_rule.protocol,
                 'remote_group_id': 'remote-group-id',
                 'used_in_default_sg': False,
-                'used_in_non_default_sg': True,
+                'used_in_non_default_sg': False,
             }
         )
         self.assertEqual(self.expected_columns, columns)
@@ -400,7 +422,7 @@ class TestCreateDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
                 'protocol': self._default_sg_rule.protocol,
                 'remote_ip_prefix': self._default_sg_rule.remote_ip_prefix,
                 'used_in_default_sg': False,
-                'used_in_non_default_sg': True,
+                'used_in_non_default_sg': False,
             }
         )
         self.assertEqual(self.expected_columns, columns)
@@ -434,7 +456,7 @@ class TestCreateDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
                 'protocol': self._default_sg_rule.protocol,
                 'remote_ip_prefix': self._default_sg_rule.remote_ip_prefix,
                 'used_in_default_sg': False,
-                'used_in_non_default_sg': True,
+                'used_in_non_default_sg': False,
             }
         )
         self.assertEqual(self.expected_columns, columns)
@@ -585,7 +607,7 @@ class TestCreateDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
                 'protocol': self._default_sg_rule.protocol,
                 'remote_ip_prefix': self._default_sg_rule.remote_ip_prefix,
                 'used_in_default_sg': False,
-                'used_in_non_default_sg': True,
+                'used_in_non_default_sg': False,
             }
         )
         self.assertEqual(self.expected_columns, columns)
@@ -623,7 +645,7 @@ class TestCreateDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
                 'protocol': self._default_sg_rule.protocol,
                 'remote_ip_prefix': self._default_sg_rule.remote_ip_prefix,
                 'used_in_default_sg': False,
-                'used_in_non_default_sg': True,
+                'used_in_non_default_sg': False,
             }
         )
         self.assertEqual(self.expected_columns, columns)
@@ -661,7 +683,7 @@ class TestCreateDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
                 'protocol': self._default_sg_rule.protocol,
                 'remote_ip_prefix': self._default_sg_rule.remote_ip_prefix,
                 'used_in_default_sg': False,
-                'used_in_non_default_sg': True,
+                'used_in_non_default_sg': False,
             }
         )
         self.assertEqual(self.expected_columns, columns)
@@ -698,7 +720,7 @@ class TestCreateDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
                 'protocol': self._default_sg_rule.protocol,
                 'remote_ip_prefix': self._default_sg_rule.remote_ip_prefix,
                 'used_in_default_sg': False,
-                'used_in_non_default_sg': True,
+                'used_in_non_default_sg': False,
             }
         )
         self.assertEqual(self.expected_columns, columns)
@@ -741,7 +763,7 @@ class TestCreateDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
                 'protocol': self._default_sg_rule.protocol,
                 'remote_ip_prefix': self._default_sg_rule.remote_ip_prefix,
                 'used_in_default_sg': False,
-                'used_in_non_default_sg': True,
+                'used_in_non_default_sg': False,
             }
         )
         self.assertEqual(self.expected_columns, columns)
@@ -780,7 +802,7 @@ class TestCreateDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
                 'protocol': self._default_sg_rule.protocol,
                 'remote_ip_prefix': self._default_sg_rule.remote_ip_prefix,
                 'used_in_default_sg': False,
-                'used_in_non_default_sg': True,
+                'used_in_non_default_sg': False,
             }
         )
         self.assertEqual(self.expected_columns, columns)
@@ -811,7 +833,7 @@ class TestCreateDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
                 'protocol': self._default_sg_rule.protocol,
                 'remote_ip_prefix': self._default_sg_rule.remote_ip_prefix,
                 'used_in_default_sg': False,
-                'used_in_non_default_sg': True,
+                'used_in_non_default_sg': False,
             }
         )
         self.assertEqual(self.expected_columns, columns)
@@ -831,7 +853,7 @@ class TestDeleteDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
         'remote_ip_prefix': '0.0.0.0/0',
         'location': 'MUNCHMUNCHMUNCH',
         'used_in_default_sg': False,
-        'used_in_non_default_sg': True,
+        'used_in_non_default_sg': False,
     }
     _default_sg_rules = list(
         sdk_fakes.generate_fake_resources(
@@ -842,13 +864,13 @@ class TestDeleteDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
     )
 
     def setUp(self):
-        super(TestDeleteDefaultSecurityGroupRule, self).setUp()
+        super().setUp()
 
         self.sdk_client.delete_default_security_group_rule.return_value = None
 
         # Get the command object to test
         self.cmd = default_security_group_rule.DeleteDefaultSecurityGroupRule(
-            self.app, self.namespace
+            self.app, None
         )
 
     def test_default_security_group_rule_delete(self):
@@ -977,7 +999,7 @@ class TestListDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
         )
 
     def setUp(self):
-        super(TestListDefaultSecurityGroupRule, self).setUp()
+        super().setUp()
 
         self.sdk_client.default_security_group_rules.return_value = (
             self._default_sg_rules
@@ -985,7 +1007,7 @@ class TestListDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
 
         # Get the command object to test
         self.cmd = default_security_group_rule.ListDefaultSecurityGroupRule(
-            self.app, self.namespace
+            self.app, None
         )
 
     def test_list_default(self):
@@ -1099,7 +1121,7 @@ class TestShowDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
     )
 
     def setUp(self):
-        super(TestShowDefaultSecurityGroupRule, self).setUp()
+        super().setUp()
 
         self.sdk_client.find_default_security_group_rule.return_value = (
             self._default_sg_rule
@@ -1107,7 +1129,7 @@ class TestShowDefaultSecurityGroupRule(TestDefaultSecurityGroupRule):
 
         # Get the command object to test
         self.cmd = default_security_group_rule.ShowDefaultSecurityGroupRule(
-            self.app, self.namespace
+            self.app, None
         )
 
     def test_show_no_options(self):
