@@ -15,7 +15,6 @@ from unittest.mock import call
 
 from osc_lib.cli import format_columns
 from osc_lib import exceptions
-from osc_lib import utils
 
 from openstackclient.network.v2 import port
 from openstackclient.tests.unit.compute.v2 import fakes as compute_fakes
@@ -30,10 +29,10 @@ LIST_FIELDS_TO_RETRIEVE_LONG = ('security_group_ids', 'device_owner', 'tags')
 
 class TestPort(network_fakes.TestNetworkV2):
     def setUp(self):
-        super(TestPort, self).setUp()
+        super().setUp()
 
         # Get a shortcut to the ProjectManager Mock
-        self.projects_mock = self.app.client_manager.identity.projects
+        self.projects_mock = self.identity_client.projects
 
     @staticmethod
     def _get_common_cols_data(fake_port):
@@ -127,7 +126,7 @@ class TestCreatePort(TestPort):
     columns, data = TestPort._get_common_cols_data(_port)
 
     def setUp(self):
-        super(TestCreatePort, self).setUp()
+        super().setUp()
 
         self.network_client.create_port = mock.Mock(return_value=self._port)
         self.network_client.set_tags = mock.Mock(return_value=None)
@@ -143,7 +142,7 @@ class TestCreatePort(TestPort):
         )
         self.network_client.find_extension = mock.Mock(return_value=[])
         # Get the command object to test
-        self.cmd = port.CreatePort(self.app, self.namespace)
+        self.cmd = port.CreatePort(self.app, None)
 
     def test_create_default_options(self):
         arglist = [
@@ -1118,14 +1117,14 @@ class TestDeletePort(TestPort):
     _ports = network_fakes.create_ports(count=2)
 
     def setUp(self):
-        super(TestDeletePort, self).setUp()
+        super().setUp()
 
         self.network_client.delete_port = mock.Mock(return_value=None)
         self.network_client.find_port = network_fakes.get_ports(
             ports=self._ports
         )
         # Get the command object to test
-        self.cmd = port.DeletePort(self.app, self.namespace)
+        self.cmd = port.DeletePort(self.app, None)
 
     def test_port_delete(self):
         arglist = [
@@ -1190,7 +1189,7 @@ class TestDeletePort(TestPort):
         self.network_client.delete_port.assert_called_once_with(self._ports[0])
 
 
-class TestListPort(TestPort):
+class TestListPort(compute_fakes.FakeClientMixin, TestPort):
     _ports = network_fakes.create_ports(count=3)
 
     columns = (
@@ -1240,7 +1239,7 @@ class TestListPort(TestPort):
         )
 
     def setUp(self):
-        super(TestListPort, self).setUp()
+        super().setUp()
 
         self.network_client.ports = mock.Mock(return_value=self._ports)
         fake_router = network_fakes.FakeRouter.create_one_router(
@@ -1256,11 +1255,8 @@ class TestListPort(TestPort):
         self.network_client.find_router = mock.Mock(return_value=fake_router)
         self.network_client.find_network = mock.Mock(return_value=fake_network)
 
-        self.app.client_manager.compute = mock.Mock()
-        self.compute_client = self.app.client_manager.compute
-
         # Get the command object to test
-        self.cmd = port.ListPort(self.app, self.namespace)
+        self.cmd = port.ListPort(self.app, None)
 
     def test_port_list_no_options(self):
         arglist = []
@@ -1297,10 +1293,9 @@ class TestListPort(TestPort):
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.data, list(data))
 
-    @mock.patch.object(utils, 'find_resource')
-    def test_port_list_with_server_option(self, mock_find):
-        fake_server = compute_fakes.create_one_server()
-        mock_find.return_value = fake_server
+    def test_port_list_with_server_option(self):
+        fake_server = compute_fakes.create_one_sdk_server()
+        self.compute_sdk_client.find_server.return_value = fake_server
 
         arglist = [
             '--server',
@@ -1315,7 +1310,9 @@ class TestListPort(TestPort):
         self.network_client.ports.assert_called_once_with(
             device_id=fake_server.id, fields=LIST_FIELDS_TO_RETRIEVE
         )
-        mock_find.assert_called_once_with(mock.ANY, 'fake-server-name')
+        self.compute_sdk_client.find_server.aassert_called_once_with(
+            mock.ANY, 'fake-server-name'
+        )
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.data, list(data))
 
@@ -1490,7 +1487,7 @@ class TestListPort(TestPort):
         ip_address = self._ports[0].fixed_ips[0]['ip_address']
         arglist = [
             '--fixed-ip',
-            "subnet=%s,ip-address=%s" % (subnet_id, ip_address),
+            f"subnet={subnet_id},ip-address={ip_address}",
         ]
         verifylist = [
             ('fixed_ip', [{'subnet': subnet_id, 'ip-address': ip_address}])
@@ -1720,7 +1717,7 @@ class TestSetPort(TestPort):
     _port = network_fakes.create_one_port({'tags': ['green', 'red']})
 
     def setUp(self):
-        super(TestSetPort, self).setUp()
+        super().setUp()
         self.fake_subnet = network_fakes.FakeSubnet.create_one_subnet()
         self.network_client.find_subnet = mock.Mock(
             return_value=self.fake_subnet
@@ -1730,7 +1727,7 @@ class TestSetPort(TestPort):
         self.network_client.set_tags = mock.Mock(return_value=None)
 
         # Get the command object to test
-        self.cmd = port.SetPort(self.app, self.namespace)
+        self.cmd = port.SetPort(self.app, None)
 
     def test_set_port_defaults(self):
         arglist = [
@@ -2507,12 +2504,12 @@ class TestShowPort(TestPort):
     columns, data = TestPort._get_common_cols_data(_port)
 
     def setUp(self):
-        super(TestShowPort, self).setUp()
+        super().setUp()
 
         self.network_client.find_port = mock.Mock(return_value=self._port)
 
         # Get the command object to test
-        self.cmd = port.ShowPort(self.app, self.namespace)
+        self.cmd = port.ShowPort(self.app, None)
 
     def test_show_no_options(self):
         arglist = []
@@ -2547,7 +2544,7 @@ class TestShowPort(TestPort):
 
 class TestUnsetPort(TestPort):
     def setUp(self):
-        super(TestUnsetPort, self).setUp()
+        super().setUp()
         self._testport = network_fakes.create_one_port(
             {
                 'fixed_ips': [
@@ -2577,7 +2574,7 @@ class TestUnsetPort(TestPort):
         self.network_client.update_port = mock.Mock(return_value=None)
         self.network_client.set_tags = mock.Mock(return_value=None)
         # Get the command object to test
-        self.cmd = port.UnsetPort(self.app, self.namespace)
+        self.cmd = port.UnsetPort(self.app, None)
 
     def test_unset_port_parameters(self):
         arglist = [
