@@ -24,12 +24,12 @@ from openstackclient.tests.unit import utils as test_utils
 
 class TestSubnetPool(network_fakes.TestNetworkV2):
     def setUp(self):
-        super(TestSubnetPool, self).setUp()
+        super().setUp()
 
         # Get a shortcut to the ProjectManager Mock
-        self.projects_mock = self.app.client_manager.identity.projects
+        self.projects_mock = self.identity_client.projects
         # Get a shortcut to the DomainManager Mock
-        self.domains_mock = self.app.client_manager.identity.domains
+        self.domains_mock = self.identity_client.domains
 
 
 class TestCreateSubnetPool(TestSubnetPool):
@@ -74,7 +74,7 @@ class TestCreateSubnetPool(TestSubnetPool):
     )
 
     def setUp(self):
-        super(TestCreateSubnetPool, self).setUp()
+        super().setUp()
 
         self.network_client.create_subnet_pool = mock.Mock(
             return_value=self._subnet_pool
@@ -82,7 +82,7 @@ class TestCreateSubnetPool(TestSubnetPool):
         self.network_client.set_tags = mock.Mock(return_value=None)
 
         # Get the command object to test
-        self.cmd = subnet_pool.CreateSubnetPool(self.app, self.namespace)
+        self.cmd = subnet_pool.CreateSubnetPool(self.app, None)
 
         self.network_client.find_address_scope = mock.Mock(
             return_value=self._address_scope
@@ -385,7 +385,7 @@ class TestDeleteSubnetPool(TestSubnetPool):
     _subnet_pools = network_fakes.FakeSubnetPool.create_subnet_pools(count=2)
 
     def setUp(self):
-        super(TestDeleteSubnetPool, self).setUp()
+        super().setUp()
 
         self.network_client.delete_subnet_pool = mock.Mock(return_value=None)
 
@@ -394,7 +394,7 @@ class TestDeleteSubnetPool(TestSubnetPool):
         )
 
         # Get the command object to test
-        self.cmd = subnet_pool.DeleteSubnetPool(self.app, self.namespace)
+        self.cmd = subnet_pool.DeleteSubnetPool(self.app, None)
 
     def test_subnet_pool_delete(self):
         arglist = [
@@ -509,10 +509,10 @@ class TestListSubnetPool(TestSubnetPool):
         )
 
     def setUp(self):
-        super(TestListSubnetPool, self).setUp()
+        super().setUp()
 
         # Get the command object to test
-        self.cmd = subnet_pool.ListSubnetPool(self.app, self.namespace)
+        self.cmd = subnet_pool.ListSubnetPool(self.app, None)
 
         self.network_client.subnet_pools = mock.Mock(
             return_value=self._subnet_pools
@@ -732,7 +732,7 @@ class TestSetSubnetPool(TestSubnetPool):
     _address_scope = network_fakes.create_one_address_scope()
 
     def setUp(self):
-        super(TestSetSubnetPool, self).setUp()
+        super().setUp()
 
         self.network_client.update_subnet_pool = mock.Mock(return_value=None)
         self.network_client.set_tags = mock.Mock(return_value=None)
@@ -746,7 +746,7 @@ class TestSetSubnetPool(TestSubnetPool):
         )
 
         # Get the command object to test
-        self.cmd = subnet_pool.SetSubnetPool(self.app, self.namespace)
+        self.cmd = subnet_pool.SetSubnetPool(self.app, None)
 
     def test_set_this(self):
         arglist = [
@@ -1077,14 +1077,14 @@ class TestShowSubnetPool(TestSubnetPool):
     )
 
     def setUp(self):
-        super(TestShowSubnetPool, self).setUp()
+        super().setUp()
 
         self.network_client.find_subnet_pool = mock.Mock(
             return_value=self._subnet_pool
         )
 
         # Get the command object to test
-        self.cmd = subnet_pool.ShowSubnetPool(self.app, self.namespace)
+        self.cmd = subnet_pool.ShowSubnetPool(self.app, None)
 
     def test_show_no_options(self):
         arglist = []
@@ -1118,7 +1118,7 @@ class TestShowSubnetPool(TestSubnetPool):
 
 class TestUnsetSubnetPool(TestSubnetPool):
     def setUp(self):
-        super(TestUnsetSubnetPool, self).setUp()
+        super().setUp()
         self._subnetpool = network_fakes.FakeSubnetPool.create_one_subnet_pool(
             {'tags': ['green', 'red']}
         )
@@ -1128,7 +1128,7 @@ class TestUnsetSubnetPool(TestSubnetPool):
         self.network_client.update_subnet_pool = mock.Mock(return_value=None)
         self.network_client.set_tags = mock.Mock(return_value=None)
         # Get the command object to test
-        self.cmd = subnet_pool.UnsetSubnetPool(self.app, self.namespace)
+        self.cmd = subnet_pool.UnsetSubnetPool(self.app, None)
 
     def _test_unset_tags(self, with_tags=True):
         if with_tags:
