@@ -26,6 +26,7 @@ from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
 
+from openstackclient.common import pagination
 from openstackclient.i18n import _
 
 
@@ -44,7 +45,7 @@ class AttachmentsColumn(cliff_columns.FormattableColumn):
     """
 
     def __init__(self, value, server_cache=None):
-        super(AttachmentsColumn, self).__init__(value)
+        super().__init__(value)
         self._server_cache = server_cache or {}
 
     def human_readable(self):
@@ -59,7 +60,7 @@ class AttachmentsColumn(cliff_columns.FormattableColumn):
             if server in self._server_cache.keys():
                 server = self._server_cache[server].name
             device = attachment['device']
-            msg += 'Attached to %s on %s ' % (server, device)
+            msg += f'Attached to {server} on {device} '
         return msg
 
 
@@ -82,7 +83,7 @@ class CreateVolume(command.ShowOne):
     _description = _("Create new volume")
 
     def get_parser(self, prog_name):
-        parser = super(CreateVolume, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'name',
             metavar='<name>',
@@ -297,7 +298,7 @@ class DeleteVolume(command.Command):
     _description = _("Delete volume(s)")
 
     def get_parser(self, prog_name):
-        parser = super(DeleteVolume, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'volumes',
             metavar='<volume>',
@@ -349,7 +350,7 @@ class ListVolume(command.Lister):
     _description = _("List volumes")
 
     def get_parser(self, prog_name):
-        parser = super(ListVolume, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             '--name',
             metavar='<name>',
@@ -372,25 +373,11 @@ class ListVolume(command.Lister):
             default=False,
             help=_('List additional fields in output'),
         )
-        parser.add_argument(
-            '--offset',
-            type=int,
-            action=parseractions.NonNegativeAction,
-            metavar='<offset>',
-            help=_('Index from which to start listing volumes'),
-        )
-        parser.add_argument(
-            '--limit',
-            type=int,
-            action=parseractions.NonNegativeAction,
-            metavar='<num-volumes>',
-            help=_('Maximum number of volumes to display'),
-        )
+        pagination.add_offset_pagination_option_to_parser(parser)
         return parser
 
     def take_action(self, parsed_args):
         volume_client = self.app.client_manager.volume
-        compute_client = self.app.client_manager.compute
 
         if parsed_args.long:
             columns = (
@@ -432,11 +419,12 @@ class ListVolume(command.Lister):
         # Cache the server list
         server_cache = {}
         try:
-            for s in compute_client.servers.list():
+            compute_client = self.app.client_manager.sdk_connection.compute
+            for s in compute_client.servers():
                 server_cache[s.id] = s
         except Exception:
             # Just forget it if there's any trouble
-            pass
+            pass  # nosec: B110
         AttachmentsColumnWithCache = functools.partial(
             AttachmentsColumn, server_cache=server_cache
         )
@@ -478,7 +466,7 @@ class MigrateVolume(command.Command):
     _description = _("Migrate volume to a new host")
 
     def get_parser(self, prog_name):
-        parser = super(MigrateVolume, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'volume',
             metavar="<volume>",
@@ -516,7 +504,7 @@ class SetVolume(command.Command):
     _description = _("Set volume properties")
 
     def get_parser(self, prog_name):
-        parser = super(SetVolume, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'volume',
             metavar='<volume>',
@@ -675,7 +663,7 @@ class ShowVolume(command.ShowOne):
     _description = _("Show volume details")
 
     def get_parser(self, prog_name):
-        parser = super(ShowVolume, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'volume',
             metavar='<volume>',
@@ -718,7 +706,7 @@ class UnsetVolume(command.Command):
     _description = _("Unset volume properties")
 
     def get_parser(self, prog_name):
-        parser = super(UnsetVolume, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'volume',
             metavar='<volume>',
