@@ -42,7 +42,7 @@ class VolumeIdColumn(cliff_columns.FormattableColumn):
     """
 
     def __init__(self, value, volume_cache=None):
-        super(VolumeIdColumn, self).__init__(value)
+        super().__init__(value)
         self._volume_cache = volume_cache or {}
 
     def human_readable(self):
@@ -61,7 +61,7 @@ class CreateVolumeBackup(command.ShowOne):
     _description = _("Create new volume backup")
 
     def get_parser(self, prog_name):
-        parser = super(CreateVolumeBackup, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'volume',
             metavar='<volume>',
@@ -105,7 +105,7 @@ class DeleteVolumeBackup(command.Command):
     _description = _("Delete volume backup(s)")
 
     def get_parser(self, prog_name):
-        parser = super(DeleteVolumeBackup, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'backups',
             metavar='<backup>',
@@ -145,7 +145,7 @@ class ListVolumeBackup(command.Lister):
     _description = _("List volume backups")
 
     def get_parser(self, prog_name):
-        parser = super(ListVolumeBackup, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             '--long',
             action='store_true',
@@ -217,7 +217,7 @@ class ListVolumeBackup(command.Lister):
                 volume_cache[s.id] = s
         except Exception:
             # Just forget it if there's any trouble
-            pass
+            pass  # nosec: B110
         VolumeIdColumnWithCache = functools.partial(
             VolumeIdColumn, volume_cache=volume_cache
         )
@@ -254,7 +254,7 @@ class RestoreVolumeBackup(command.Command):
     _description = _("Restore volume backup")
 
     def get_parser(self, prog_name):
-        parser = super(RestoreVolumeBackup, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'backup',
             metavar='<backup>',
@@ -287,7 +287,7 @@ class ShowVolumeBackup(command.ShowOne):
     _description = _("Display volume backup details")
 
     def get_parser(self, prog_name):
-        parser = super(ShowVolumeBackup, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'backup',
             metavar='<backup>',
