@@ -20,6 +20,7 @@ import functools
 import logging
 
 from cliff import columns as cliff_columns
+from openstack import exceptions as sdk_exceptions
 from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
 from osc_lib.command import command
@@ -69,7 +70,7 @@ class AttachmentsColumn(cliff_columns.FormattableColumn):
     """
 
     def __init__(self, value, server_cache=None):
-        super(AttachmentsColumn, self).__init__(value)
+        super().__init__(value)
         self._server_cache = server_cache or {}
 
     def human_readable(self):
@@ -84,31 +85,29 @@ class AttachmentsColumn(cliff_columns.FormattableColumn):
             if server in self._server_cache.keys():
                 server = self._server_cache[server].name
             device = attachment['device']
-            msg += 'Attached to %s on %s ' % (server, device)
+            msg += f'Attached to {server} on {device} '
         return msg
 
 
-def _check_size_arg(args):
-    """Check whether --size option is required or not.
-
-    Require size parameter only in case when snapshot or source
-    volume is not specified.
-    """
-
-    if (
-        args.snapshot or args.source or args.backup
-    ) is None and args.size is None:
-        msg = _(
-            "--size is a required option if snapshot, backup "
-            "or source volume are not specified."
-        )
-        raise exceptions.CommandError(msg)
-
-
 class CreateVolume(command.ShowOne):
     _description = _("Create new volume")
 
-    def get_parser(self, prog_name):
+    @staticmethod
+    def _check_size_arg(args):
+        """Check whether --size option is required or not.
+
+        Require size parameter only in case when snapshot or source
+        volume is not specified.
+        """
+
+        if (args.snapshot or args.source) is None and args.size is None:
+            msg = _(
+                "--size is a required option if --snapshot or --source are "
+                "not specified"
+            )
+            raise exceptions.CommandError(msg)
+
+    def _get_parser(self, prog_name):
         parser = super().get_parser(prog_name)
         parser.add_argument(
             "name",
@@ -121,8 +120,8 @@ class CreateVolume(command.ShowOne):
             metavar="<size>",
             type=int,
             help=_(
-                "Volume size in GB (required unless --snapshot, "
-                "--source or --backup is specified)"
+                "Volume size in GB (required unless --snapshot or "
+                "--source specified)"
             ),
         )
         parser.add_argument(
@@ -146,14 +145,6 @@ class CreateVolume(command.ShowOne):
             metavar="<volume>",
             help=_("Volume to clone (name or ID)"),
         )
-        source_group.add_argument(
-            "--backup",
-            metavar="<backup>",
-            help=_(
-                "Restore backup to a volume (name or ID) "
-                "(supported by --os-volume-api-version 3.47 or later)"
-            ),
-        )
         source_group.add_argument(
             "--source-replicated",
             metavar="<replicated-volume>",
@@ -216,28 +207,23 @@ class CreateVolume(command.ShowOne):
             action="store_true",
             help=_("Set volume to read-write access mode (default)"),
         )
+        return parser, source_group
+
+    def get_parser(self, prog_name):
+        parser, _ = self._get_parser(prog_name)
         return parser
 
     def take_action(self, parsed_args):
-        _check_size_arg(parsed_args)
+        CreateVolume._check_size_arg(parsed_args)
         # size is validated in the above call to
         # _check_size_arg where we check that size
         # should be passed if we are not creating a
-        # volume from snapshot, backup or source volume
+        # volume from snapshot or source volume
         size = parsed_args.size
 
         volume_client = self.app.client_manager.volume
         image_client = self.app.client_manager.image
 
-        if parsed_args.backup and not (
-            volume_client.api_version.matches('3.47')
-        ):
-            msg = _(
-                "--os-volume-api-version 3.47 or greater is required "
-                "to create a volume from backup."
-            )
-            raise exceptions.CommandError(msg)
-
         source_volume = None
         if parsed_args.source:
             source_volume_obj = utils.find_resource(
@@ -272,15 +258,6 @@ class CreateVolume(command.ShowOne):
             # snapshot size.
             size = max(size or 0, snapshot_obj.size)
 
-        backup = None
-        if parsed_args.backup:
-            backup_obj = utils.find_resource(
-                volume_client.backups, parsed_args.backup
-            )
-            backup = backup_obj.id
-            # As above
-            size = max(size or 0, backup_obj.size)
-
         volume = volume_client.volumes.create(
             size=size,
             snapshot_id=snapshot,
@@ -293,7 +270,6 @@ class CreateVolume(command.ShowOne):
             source_volid=source_volume,
             consistencygroup_id=consistency_group,
             scheduler_hints=parsed_args.hint,
-            backup_id=backup,
         )
 
         if parsed_args.bootable or parsed_args.non_bootable:
@@ -360,7 +336,7 @@ class DeleteVolume(command.Command):
     _description = _("Delete volume(s)")
 
     def get_parser(self, prog_name):
-        parser = super(DeleteVolume, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             "volumes",
             metavar="<volume>",
@@ -422,7 +398,7 @@ class ListVolume(command.Lister):
     _description = _("List volumes")
 
     def get_parser(self, prog_name):
-        parser = super(ListVolume, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             '--project',
             metavar='<project>',
@@ -490,19 +466,6 @@ class ListVolume(command.Lister):
             column_headers = copy.deepcopy(columns)
             column_headers[4] = 'Attached to'
 
-        # Cache the server list
-        server_cache = {}
-        try:
-            compute_client = self.app.client_manager.compute
-            for s in compute_client.servers.list():
-                server_cache[s.id] = s
-        except Exception:
-            # Just forget it if there's any trouble
-            pass
-        AttachmentsColumnWithCache = functools.partial(
-            AttachmentsColumn, server_cache=server_cache
-        )
-
         project_id = None
         if parsed_args.project:
             project_id = identity_common.find_project(
@@ -533,6 +496,28 @@ class ListVolume(command.Lister):
             marker=parsed_args.marker,
             limit=parsed_args.limit,
         )
+
+        do_server_list = False
+
+        for vol in data:
+            if vol.status == 'in-use':
+                do_server_list = True
+                break
+
+        # Cache the server list
+        server_cache = {}
+        if do_server_list:
+            try:
+                compute_client = self.app.client_manager.sdk_connection.compute
+                for s in compute_client.servers():
+                    server_cache[s.id] = s
+            except sdk_exceptions.SDKException:
+                # Just forget it if there's any trouble
+                pass  # nosec: B110
+        AttachmentsColumnWithCache = functools.partial(
+            AttachmentsColumn, server_cache=server_cache
+        )
+
         column_headers = utils.backward_compat_col_lister(
             column_headers, parsed_args.columns, {'Display Name': 'Name'}
         )
@@ -557,7 +542,7 @@ class MigrateVolume(command.Command):
     _description = _("Migrate volume to a new host")
 
     def get_parser(self, prog_name):
-        parser = super(MigrateVolume, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'volume',
             metavar="<volume>",
@@ -605,7 +590,7 @@ class SetVolume(command.Command):
     _description = _("Set volume properties")
 
     def get_parser(self, prog_name):
-        parser = super(SetVolume, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'volume',
             metavar='<volume>',
@@ -711,6 +696,12 @@ class SetVolume(command.Command):
             '--retype-policy',
             metavar='<retype-policy>',
             choices=['never', 'on-demand'],
+            help=argparse.SUPPRESS,
+        )
+        parser.add_argument(
+            '--migration-policy',
+            metavar='<migration-policy>',
+            choices=['never', 'on-demand'],
             help=_(
                 'Migration policy while re-typing volume '
                 '("never" or "on-demand", default is "never" ) '
@@ -746,6 +737,15 @@ class SetVolume(command.Command):
         volume = utils.find_resource(volume_client.volumes, parsed_args.volume)
 
         result = 0
+        if parsed_args.retype_policy:
+            msg = _(
+                "The '--retype-policy' option has been deprecated in favor "
+                "of '--migration-policy' option. The '--retype-policy' option "
+                "will be removed in a future release. Please use "
+                "'--migration-policy' instead."
+            )
+            self.log.warning(msg)
+
         if parsed_args.size:
             try:
                 if parsed_args.size <= volume.size:
@@ -753,10 +753,7 @@ class SetVolume(command.Command):
                         _("New size must be greater than %s GB") % volume.size
                     )
                     raise exceptions.CommandError(msg)
-                if (
-                    volume.status != 'available'
-                    and not volume_client.api_version.matches('3.42')
-                ):
+                if volume.status != 'available':
                     msg = (
                         _(
                             "Volume is in %s state, it must be available "
@@ -839,11 +836,12 @@ class SetVolume(command.Command):
                     e,
                 )
                 result += 1
+        policy = parsed_args.migration_policy or parsed_args.retype_policy
         if parsed_args.type:
             # get the migration policy
             migration_policy = 'never'
-            if parsed_args.retype_policy:
-                migration_policy = parsed_args.retype_policy
+            if policy:
+                migration_policy = policy
             try:
                 # find the volume type
                 volume_type = utils.find_resource(
@@ -856,12 +854,14 @@ class SetVolume(command.Command):
             except Exception as e:
                 LOG.error(_("Failed to set volume type: %s"), e)
                 result += 1
-        elif parsed_args.retype_policy:
-            # If the "--retype-policy" is specified without "--type"
+        elif policy:
+            # If the "--migration-policy" is specified without "--type"
             LOG.warning(
-                _(
-                    "'--retype-policy' option will not work "
-                    "without '--type' option"
+                _("'%s' option will not work without '--type' option")
+                % (
+                    '--migration-policy'
+                    if parsed_args.migration_policy
+                    else '--retype-policy'
                 )
             )
 
@@ -893,7 +893,7 @@ class ShowVolume(command.ShowOne):
     _description = _("Display volume details")
 
     def get_parser(self, prog_name):
-        parser = super(ShowVolume, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'volume',
             metavar="<volume>",
@@ -926,7 +926,7 @@ class UnsetVolume(command.Command):
     _description = _("Unset volume properties")
 
     def get_parser(self, prog_name):
-        parser = super(UnsetVolume, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'volume',
             metavar='<volume>',
