@@ -43,7 +43,7 @@ class EncryptionInfoColumn(cliff_columns.FormattableColumn):
     """
 
     def __init__(self, value, encryption_data=None):
-        super(EncryptionInfoColumn, self).__init__(value)
+        super().__init__(value)
         self._encryption_data = encryption_data or {}
 
     def _get_encryption_info(self):
@@ -109,7 +109,7 @@ class CreateVolumeType(command.ShowOne):
     _description = _("Create new volume type")
 
     def get_parser(self, prog_name):
-        parser = super(CreateVolumeType, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             "name",
             metavar="<name>",
@@ -139,19 +139,61 @@ class CreateVolumeType(command.ShowOne):
             '--property',
             metavar='<key=value>',
             action=parseractions.KeyValueAction,
+            dest='properties',
             help=_(
                 'Set a property on this volume type '
                 '(repeat option to set multiple properties)'
             ),
         )
+        parser.add_argument(
+            '--multiattach',
+            action='store_true',
+            default=False,
+            help=_(
+                "Enable multi-attach for this volume type "
+                "(this is an alias for '--property multiattach=<is> True') "
+                "(requires driver support)"
+            ),
+        )
+        parser.add_argument(
+            '--cacheable',
+            action='store_true',
+            default=False,
+            help=_(
+                "Enable caching for this volume type "
+                "(this is an alias for '--property cacheable=<is> True') "
+                "(requires driver support)"
+            ),
+        )
+        parser.add_argument(
+            '--replicated',
+            action='store_true',
+            default=False,
+            help=_(
+                "Enabled replication for this volume type "
+                "(this is an alias for '--property replication_enabled=<is> True') "  # noqa: E501
+                "(requires driver support)"
+            ),
+        )
+        parser.add_argument(
+            '--availability-zone',
+            action='append',
+            dest='availability_zones',
+            help=_(
+                "Set an availability zone for this volume type "
+                "(this is an alias for '--property RESKEY:availability_zones:<az>') "  # noqa: E501
+                "(repeat option to set multiple availability zones)"
+            ),
+        )
         parser.add_argument(
             '--project',
             metavar='<project>',
             help=_(
                 "Allow <project> to access private type (name or ID) "
-                "(Must be used with --private option)"
+                "(must be used with --private option)"
             ),
         )
+        identity_common.add_project_domain_option_to_parser(parser)
         # TODO(Huanxuan Ao): Add choices for each "--encryption-*" option.
         parser.add_argument(
             '--encryption-provider',
@@ -159,8 +201,8 @@ class CreateVolumeType(command.ShowOne):
             help=_(
                 'Set the encryption provider format for '
                 'this volume type (e.g "luks" or "plain") (admin only) '
-                '(This option is required when setting encryption type '
-                'of a volume. Consider using other encryption options '
+                '(this option is required when setting encryption type '
+                'of a volume; consider using other encryption options '
                 'such as: "--encryption-cipher", "--encryption-key-size" '
                 'and "--encryption-control-location")'
             ),
@@ -196,7 +238,6 @@ class CreateVolumeType(command.ShowOne):
                 '"--encryption-provider")'
             ),
         )
-        identity_common.add_project_domain_option_to_parser(parser)
         return parser
 
     def take_action(self, parsed_args):
@@ -208,11 +249,14 @@ class CreateVolumeType(command.ShowOne):
             raise exceptions.CommandError(msg)
 
         kwargs = {}
+
         if parsed_args.is_public is not None:
             kwargs['is_public'] = parsed_args.is_public
 
         volume_type = volume_client.volume_types.create(
-            parsed_args.name, description=parsed_args.description, **kwargs
+            parsed_args.name,
+            description=parsed_args.description,
+            **kwargs,
         )
         volume_type._info.pop('extra_specs')
 
@@ -232,11 +276,26 @@ class CreateVolumeType(command.ShowOne):
                     "type: %(e)s"
                 )
                 LOG.error(msg % {'project': parsed_args.project, 'e': e})
-        if parsed_args.property:
-            result = volume_type.set_keys(parsed_args.property)
+
+        properties = {}
+        if parsed_args.properties:
+            properties.update(parsed_args.properties)
+        if parsed_args.multiattach:
+            properties['multiattach'] = '<is> True'
+        if parsed_args.cacheable:
+            properties['cacheable'] = '<is> True'
+        if parsed_args.replicated:
+            properties['replication_enabled'] = '<is> True'
+        if parsed_args.availability_zones:
+            properties['RESKEY:availability_zones'] = ','.join(
+                parsed_args.availability_zones
+            )
+        if properties:
+            result = volume_type.set_keys(properties)
             volume_type._info.update(
                 {'properties': format_columns.DictColumn(result)}
             )
+
         if (
             parsed_args.encryption_provider
             or parsed_args.encryption_cipher
@@ -261,6 +320,7 @@ class CreateVolumeType(command.ShowOne):
             volume_type._info.update(
                 {'encryption': format_columns.DictColumn(encryption._info)}
             )
+
         volume_type._info.pop("os-volume-type-access:is_public", None)
 
         return zip(*sorted(volume_type._info.items()))
@@ -270,7 +330,7 @@ class DeleteVolumeType(command.Command):
     _description = _("Delete volume type(s)")
 
     def get_parser(self, prog_name):
-        parser = super(DeleteVolumeType, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             "volume_types",
             metavar="<volume-type>",
@@ -312,7 +372,7 @@ class ListVolumeType(command.Lister):
     _description = _("List volume types")
 
     def get_parser(self, prog_name):
-        parser = super(ListVolumeType, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             '--long',
             action='store_true',
@@ -359,14 +419,12 @@ class ListVolumeType(command.Lister):
                 'Name',
                 'Is Public',
                 'Description',
-                'Extra Specs',
             ]
             column_headers = [
                 'ID',
                 'Name',
                 'Is Public',
                 'Description',
-                'Properties',
             ]
         else:
             columns = ['ID', 'Name', 'Is Public']
@@ -376,7 +434,7 @@ class ListVolumeType(command.Lister):
             data = [volume_client.volume_types.default()]
         else:
             data = volume_client.volume_types.list(
-                is_public=parsed_args.is_public
+                is_public=parsed_args.is_public,
             )
 
         formatters = {'Extra Specs': format_columns.DictColumn}
@@ -425,7 +483,7 @@ class SetVolumeType(command.Command):
     _description = _("Set volume type properties")
 
     def get_parser(self, prog_name):
-        parser = super(SetVolumeType, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'volume_type',
             metavar='<volume-type>',
@@ -445,11 +503,52 @@ class SetVolumeType(command.Command):
             '--property',
             metavar='<key=value>',
             action=parseractions.KeyValueAction,
+            dest='properties',
             help=_(
                 'Set a property on this volume type '
                 '(repeat option to set multiple properties)'
             ),
         )
+        parser.add_argument(
+            '--multiattach',
+            action='store_true',
+            default=False,
+            help=_(
+                "Enable multi-attach for this volume type "
+                "(this is an alias for '--property multiattach=<is> True') "
+                "(requires driver support)"
+            ),
+        )
+        parser.add_argument(
+            '--cacheable',
+            action='store_true',
+            default=False,
+            help=_(
+                "Enable caching for this volume type "
+                "(this is an alias for '--property cacheable=<is> True') "
+                "(requires driver support)"
+            ),
+        )
+        parser.add_argument(
+            '--replicated',
+            action='store_true',
+            default=False,
+            help=_(
+                "Enabled replication for this volume type "
+                "(this is an alias for '--property replication_enabled=<is> True') "  # noqa: E501
+                "(requires driver support)"
+            ),
+        )
+        parser.add_argument(
+            '--availability-zone',
+            action='append',
+            dest='availability_zones',
+            help=_(
+                "Set an availability zone for this volume type "
+                "(this is an alias for '--property RESKEY:availability_zones:<az>') "  # noqa: E501
+                "(repeat option to set multiple availability zones)"
+            ),
+        )
         parser.add_argument(
             '--project',
             metavar='<project>',
@@ -555,11 +654,26 @@ class SetVolumeType(command.Command):
                 )
                 result += 1
 
-        if parsed_args.property:
+        properties = {}
+
+        properties = {}
+        if parsed_args.properties:
+            properties.update(parsed_args.properties)
+        if parsed_args.multiattach:
+            properties['multiattach'] = '<is> True'
+        if parsed_args.cacheable:
+            properties['cacheable'] = '<is> True'
+        if parsed_args.replicated:
+            properties['replication_enabled'] = '<is> True'
+        if parsed_args.availability_zones:
+            properties['RESKEY:availability_zones'] = ','.join(
+                parsed_args.availability_zones
+            )
+        if properties:
             try:
-                volume_type.set_keys(parsed_args.property)
+                volume_type.set_keys(properties)
             except Exception as e:
-                LOG.error(_("Failed to set volume type property: %s"), e)
+                LOG.error(_("Failed to set volume type properties: %s"), e)
                 result += 1
 
         if parsed_args.project:
@@ -608,7 +722,7 @@ class ShowVolumeType(command.ShowOne):
     _description = _("Display volume type details")
 
     def get_parser(self, prog_name):
-        parser = super(ShowVolumeType, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             "volume_type",
             metavar="<volume-type>",
@@ -679,7 +793,7 @@ class UnsetVolumeType(command.Command):
     _description = _("Unset volume type properties")
 
     def get_parser(self, prog_name):
-        parser = super(UnsetVolumeType, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'volume_type',
             metavar='<volume-type>',
@@ -689,6 +803,7 @@ class UnsetVolumeType(command.Command):
             '--property',
             metavar='<key>',
             action='append',
+            dest='properties',
             help=_(
                 'Remove a property from this volume type '
                 '(repeat option to remove multiple properties)'
@@ -723,11 +838,11 @@ class UnsetVolumeType(command.Command):
         )
 
         result = 0
-        if parsed_args.property:
+        if parsed_args.properties:
             try:
-                volume_type.unset_keys(parsed_args.property)
+                volume_type.unset_keys(parsed_args.properties)
             except Exception as e:
-                LOG.error(_("Failed to unset volume type property: %s"), e)
+                LOG.error(_("Failed to unset volume type properties: %s"), e)
                 result += 1
 
         if parsed_args.project:
